==> zio-aws-iottwinmaker_2.13-5.17.153.3-sources.jar: zio/aws/iottwinmaker/model/DeleteComponentTypeRequest.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.{Id, ComponentTypeId}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteComponentTypeRequest(
    componentTypeId: ComponentTypeId,
    workspaceId: Id
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest = {
    import DeleteComponentTypeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
      .builder()
      .componentTypeId(
        ComponentTypeId.unwrap(componentTypeId): java.lang.String
      )
      .workspaceId(Id.unwrap(workspaceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.ReadOnly =
    zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.wrap(buildAwsValue())
}
object DeleteComponentTypeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.DeleteComponentTypeRequest =
      zio.aws.iottwinmaker.model
        .DeleteComponentTypeRequest(componentTypeId, workspaceId)
    def componentTypeId: ComponentTypeId
    def workspaceId: Id
    def getComponentTypeId: ZIO[Any, Nothing, ComponentTypeId] =
      ZIO.succeed(componentTypeId)
    def getWorkspaceId: ZIO[Any, Nothing, Id] = ZIO.succeed(workspaceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
  ) extends zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.ReadOnly {
    override val componentTypeId: ComponentTypeId =
      zio.aws.iottwinmaker.model.primitives
        .ComponentTypeId(impl.componentTypeId())
    override val workspaceId: Id =
      zio.aws.iottwinmaker.model.primitives.Id(impl.workspaceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
  ): zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iottwinmaker_2.13-5.19.7.5-sources.jar: zio/aws/iottwinmaker/model/DeleteComponentTypeRequest.scala <==
package zio.aws.iottwinmaker.model
import zio.aws.iottwinmaker.model.primitives.{ComponentTypeId, Id}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteComponentTypeRequest(
    workspaceId: Id,
    componentTypeId: ComponentTypeId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest = {
    import DeleteComponentTypeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
      .builder()
      .workspaceId(Id.unwrap(workspaceId): java.lang.String)
      .componentTypeId(
        ComponentTypeId.unwrap(componentTypeId): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.ReadOnly =
    zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.wrap(buildAwsValue())
}
object DeleteComponentTypeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iottwinmaker.model.DeleteComponentTypeRequest =
      zio.aws.iottwinmaker.model
        .DeleteComponentTypeRequest(workspaceId, componentTypeId)
    def workspaceId: Id
    def componentTypeId: ComponentTypeId
    def getWorkspaceId: ZIO[Any, Nothing, Id] = ZIO.succeed(workspaceId)
    def getComponentTypeId: ZIO[Any, Nothing, ComponentTypeId] =
      ZIO.succeed(componentTypeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
  ) extends zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.ReadOnly {
    override val workspaceId: Id =
      zio.aws.iottwinmaker.model.primitives.Id(impl.workspaceId())
    override val componentTypeId: ComponentTypeId =
      zio.aws.iottwinmaker.model.primitives
        .ComponentTypeId(impl.componentTypeId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iottwinmaker.model.DeleteComponentTypeRequest
  ): zio.aws.iottwinmaker.model.DeleteComponentTypeRequest.ReadOnly =
    new Wrapper(impl)
}
